@@ -14,14 +14,14 @@ cargo install arcboot
 # build for riscv64
 cargo arcboot build spectro --test 
 # run the test cfg. Note, `cargo arcboot test spectro` does the two commands together
-cargo arcboot run --test
+# cargo arcboot run --test
 
 # when ready, build and run the release config
-cargo arcboot run --release
+# cargo arcboot run --release
 
 ##
 # PI4B
 ##
 
 # build for aarch64
-cargo arcboot build aarch64
+# cargo arcboot build aarch64
